function PCAScatterPlot(Samples, Color, Marker)
//////////////////////////////////////////////////////////////////////////// 
// CLUSTER - Clustering Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2011
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////

  // Input and output parameters are checked.
 
 [NumberOfOutputs NumberOfInputs] = argn();
 
 if NumberOfInputs ~= 3 then
 
  error('Wrong number of inputs.');
  
 end;
 
 // Samples must be a matrix.
 
 if (typeof(Samples) ~= 'constant') | (ndims(Samples) ~= 2)  then
  
  error('Samples must be a 2D matrix.');
  
 end;
 
 // Color must be a string and can be 'r' (red), 'y' (yellow), 'g' (green),
 // 'c' (cyan), 'b' (blue), 'm' (magenta) or 'k' (black).
 
 if typeof(Color) ~= 'string'
 
  error('Color must be a string.');
  
 end;

 if length(Color) > 1 then
  
  error('Unknown color.');
  
 end;
 
 AdmittedColors = ['r', 'y', 'g', 'c', 'b', 'm', 'k'];
 
 if isempty(find(convstr(Color, 'l') == AdmittedColors)) then
  
  error('Unknown color.');
  
 end;

 // Marker must be a string and can be '.' (point), 'o' (circle), '+' (plus),
 // '*' (asterisk) or 'x' (cross).
 
 if typeof(Marker) ~= 'string'
 
  error('Marker must be a string.');
  
 end;

 if length(Marker) > 1 then
  
  error('Unknown marker.');
  
 end;
 
 AdmittedMarkers = ['.', 'o', '+', '*', 'x'];
 
 if isempty(find(Marker == AdmittedMarkers)) then
  
  error('Unknown marker.');
  
 end;
 
 if NumberOfOutputs > 1 then

  error('Wrong number of outputs.');

 end;
 
 // A principal component analysis is performed. The principal components that 
 // correspond to the two biggest eigenvalues are selected.
 
 if size(Samples, 2) > 1 then

  [Eigenvectors, PrincipalComponents, Eigenvalues, TSquare] = ...
  princomp(Samples, %t);

 else

  // If Samples has only one column, this column is repeated so there are two.
  
  [Eigenvectors, PrincipalComponents, Eigenvalues, TSquare] = ...
  princomp(repmat(Samples, 1, 2), %t);

 end;
 
 // The selected principal components are plotted.
 
 plot(PrincipalComponents(:, 1)', ...
      PrincipalComponents(:, 2)', ...
      strcat([Color, Marker]));

endfunction