function QuantizationError = FuzzyQuantizationError(Samples, ...
                                                    Centers, ...
                                                    Memberships, ...
                                                    NormType, ...
                                                    Blending)
//////////////////////////////////////////////////////////////////////////// 
// CLUSTER - Clustering Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2011
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////


 // Input and output parameters are checked.
 
 [NumberOfOutputs NumberOfInputs] = argn();
 
 if (NumberOfInputs < 4) | (NumberOfInputs > 5) then
 
  error('Wrong number of inputs.');
  
 end;
 
 // Samples must be a matrix.
 
 if (typeof(Samples) ~= 'constant') | (ndims(Samples) ~= 2)  then
  
  error('Samples must be a 2D matrix.');
  
 end;
 
 // Centers must be a matrix.
 
 if (typeof(Centers) ~= 'constant') | (ndims(Centers) ~= 2)  then
  
  error('Centers must be a 2D matrix.');
  
 end;
 
 // Samples and Centers must have the same number of columns.
 
 if size(Samples, 2) ~= size(Centers, 2) then
  
  error('Samples and Centers must have the same number of columns');
  
 end;
 
 // Membership must be a matrix that has the same number of rows as Samples and
 // the same number of columns as the number of rows of Centers.
 
 if (ndims(Memberships) ~= 2) | (typeof(Memberships) ~= 'constant') then
  
  error('Membership must be a 2D matrix.');
 
 end;

 if ~isequal(size(Memberships), [size(Samples, 1) size(Centers, 1)]) then

  error('Membership must have as many rows as the number of sampples ' + ...
        'and as many columns as the number of centers');

 end;

 // NormType must be a scalar greater than zero.
 
 if (typeof(NormType) ~= 'constant') | (~isequal(size(NormType), [1 1])) then
 
  error('NormType must be a scalar greater than zero.');
 
 end;
 
 if NormType <= 0 then
  
  error('NormType must be a scalar greater than zero.');
  
 end;
 
 // Blending must be a scalar greater than one.
 
 if NumberOfInputs == 5 then

  if (typeof(Blending) ~= 'constant') | (~isequal(size(Blending), [1 1])) then
 
  error('Blending must be a scalar greater than one.');
 
  end;
 
  if Blending <= 1 then
  
   error('Blending must be a scalar greater than one.');
  
  end;
 
 else

  Blending = 2;
    
 end;

 if NumberOfOutputs ~= 1 then
  
  error('Wrong number of outputs.');
  
 end;
 
 // The fuzzy quantization error is calculated.
 
 SquaredDistances = CreateDistanceMatrix(Samples, Centers, NormType);
 
 SquaredDistances = SquaredDistances .^ 2;
 
 QuantizationError = sum((Memberships .^ Blending) .* SquaredDistances);
 
endfunction